"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const autoBind = require("auto-bind");
const graphql_codegen_visitor_plugin_common_1 = require("graphql-codegen-visitor-plugin-common");
const graphql_codegen_flow_1 = require("graphql-codegen-flow");
class FlowResolversVisitor extends graphql_codegen_visitor_plugin_common_1.BaseResolversVisitor {
    constructor(pluginConfig, schema) {
        super(pluginConfig, null, schema);
        autoBind(this);
        this.setVariablesTransformer(new graphql_codegen_flow_1.FlowOperationVariablesToObject(this.config.scalars, this.convertName));
    }
    formatRootResolver(schemaTypeName, resolverType) {
        return `${schemaTypeName}?: ${resolverType}<>,`;
    }
    _getScalar(name) {
        return `$ElementType<Scalars, '${name}'>`;
    }
    buildMapperImport(source, types) {
        return `import { ${types.map(t => `type ${t}`).join(', ')} } from '${source}';`;
    }
    ListType(node) {
        return `?${super.ListType(node)}`;
    }
    NamedType(node) {
        return `?${super.NamedType(node)}`;
    }
    NonNullType(node) {
        const baseValue = super.NonNullType(node);
        if (baseValue.charAt(0) === '?') {
            return baseValue.substr(1);
        }
        return baseValue;
    }
}
exports.FlowResolversVisitor = FlowResolversVisitor;
//# sourceMappingURL=visitor.js.map