import * as autoBind from 'auto-bind';
import { BaseResolversVisitor } from 'graphql-codegen-visitor-plugin-common';
import { FlowOperationVariablesToObject } from 'graphql-codegen-flow';
export class FlowResolversVisitor extends BaseResolversVisitor {
    constructor(pluginConfig, schema) {
        super(pluginConfig, null, schema);
        autoBind(this);
        this.setVariablesTransformer(new FlowOperationVariablesToObject(this.config.scalars, this.convertName));
    }
    formatRootResolver(schemaTypeName, resolverType) {
        return `${schemaTypeName}?: ${resolverType}<>,`;
    }
    _getScalar(name) {
        return `$ElementType<Scalars, '${name}'>`;
    }
    buildMapperImport(source, types) {
        return `import { ${types.map(t => `type ${t}`).join(', ')} } from '${source}';`;
    }
    ListType(node) {
        return `?${super.ListType(node)}`;
    }
    NamedType(node) {
        return `?${super.NamedType(node)}`;
    }
    NonNullType(node) {
        const baseValue = super.NonNullType(node);
        if (baseValue.charAt(0) === '?') {
            return baseValue.substr(1);
        }
        return baseValue;
    }
}
//# sourceMappingURL=visitor.js.map